@@ -1,6 +1,4 @@
-"""
-Define the failure callback functionality
-"""
+"""Define the failure callback functionality."""
 import json
 import logging
 from contextlib import contextmanager
@@ -16,6 +14,8 @@ logger = logging.getLogger(__name__)
 
 @message_class(routing_key="recipe.run.failure.m", queues=["recipe.run.failure.q"])
 class RecipeRunFailureMessage:
+    """Message keys for recipe run failure messages."""
+
     workflowName: str
     workflowVersion: str
     taskName: str
@@ -51,6 +51,7 @@ def _isb_connection_info() -> dict:
 
 @contextmanager
 def recipe_run_failure_message_producer_factory() -> DurableBlockingProducerWrapper:
+    """Create message producer for recipe run failure messages."""
     try:
         with DurableBlockingProducerWrapper(
             producer_queue_bindings=RecipeRunFailureMessage.binding(),
@@ -63,10 +64,12 @@ def recipe_run_failure_message_producer_factory() -> DurableBlockingProducerWrap
 
 
 def parse_dag_run_id_from_context(context: dict) -> Optional[str]:
+    """Find dag run id."""
     return context.get("run_id", None)
 
 
 def parse_log_url_from_context(context: dict) -> Optional[str]:
+    """Given an airflow context, find the URL of the logs created by the task."""
     ti = context.get("task_instance", object)
     try:
         return ti.log_url
@@ -81,9 +84,7 @@ def chat_ops_notification(
     task_name: str,
     producer_factory=recipe_run_failure_message_producer_factory,
 ) -> None:
-    """
-    Publish message with information regarding a task failure for publication to a chat service
-    """
+    """Publish message with information regarding a task failure for publication to a chat service."""
     dag_run_id = parse_dag_run_id_from_context(context)
     log_url = parse_log_url_from_context(context)
     message = RecipeRunFailureMessage(
