@@ -1,6 +1,4 @@
-"""
-Global test fixtures
-"""
+"""Global test fixtures."""
 from configparser import ConfigParser
 from contextlib import contextmanager
 from pathlib import Path
@@ -21,9 +19,7 @@ from dkist_processing_core.tests.task_example import Task
 
 @pytest.fixture(scope="module")
 def export_path() -> str:
-    """
-    export path object that will be removed on teardown
-    """
+    """Export path object that will be removed on teardown."""
     path = Path("export/")
     yield str(path)
     rmtree(path)
@@ -31,19 +27,13 @@ def export_path() -> str:
 
 @pytest.fixture(scope="session")
 def task_subclass():
-    """
-    Sub class of the abstract task base class implementing methods that are expected to
-       be subclassed with inspect-able metadata
-    """
+    """Sub class of the abstract task base class implementing methods that are expected to be subclassed with inspect-able metadata."""
     return Task
 
 
 @pytest.fixture(scope="session")
 def error_task_subclass():
-    """
-    Sub class of the abstract task base class implementing methods that are expected to
-       be subclassed with inspect-able metadata
-    """
+    """Sub class of the abstract task base class implementing methods that are expected to be subclassed with inspect-able metadata."""
 
     class Task(TaskBase):
         def __init__(self, *args, **kwargs):
@@ -63,9 +53,7 @@ def error_task_subclass():
 
 @pytest.fixture()
 def task_instance(task_subclass):
-    """
-    Create an instance of the task subclass defined in task_subclass
-    """
+    """Create an instance of the task subclass defined in task_subclass."""
     with task_subclass(
         recipe_run_id=1, workflow_name="workflow_name", workflow_version="version"
     ) as task:
@@ -74,9 +62,7 @@ def task_instance(task_subclass):
 
 @pytest.fixture()
 def workflow():
-    """
-    Create an instance of the Workflow abstraction without tasks
-    """
+    """Create an instance of the Workflow abstraction without tasks."""
     category = "instrument"
     name = "calibration_name"
     version = "V6-12342"
@@ -91,9 +77,7 @@ def workflow():
 
 @pytest.fixture()
 def workflow_tasks(task_subclass) -> List[Type[TaskBase]]:
-    """
-    A list of Tasks that can be composed into a workflow
-    """
+    """List of Tasks that can be composed into a workflow."""
 
     class TaskA(task_subclass):
         pass
@@ -112,9 +96,7 @@ def workflow_tasks(task_subclass) -> List[Type[TaskBase]]:
 
 @pytest.fixture(params=["0_upstream", "1_upstream", "2_upstream"])
 def node(workflow_tasks, request) -> Tuple[Node, Type[TaskBase], Any, str, str]:
-    """
-    Node instance and its component parts
-    """
+    """Node instance and its component parts."""
     version = "V6-123"
     name = f"{request.param}_{version}"
     TaskA, TaskB, TaskC, _ = workflow_tasks
