@@ -1,14 +1,11 @@
-"""
-Test minimal dependency dag export (used for scheduler deployments)
-"""
+"""Test minimal dependency dag export (used for scheduler deployments)."""
 
 
 def test_workflow_export(workflow_tasks, workflow, export_path):
     """
-    Given: A workflow instance with tasks in the
-      structure of A >> [B, C] >> D
-    When: Exporting the dag
-    Then: The exported dag compiles
+    Given: A workflow instance with tasks in the structure of A >> [B, C] >> D.
+    When: Exporting the dag.
+    Then: The exported dag compiles.
     """
     workflow_instance, category, name, version = workflow
     TaskA, TaskB, TaskC, TaskD = workflow_tasks
