@@ -1,19 +1,15 @@
-"""
-Tests for the Workflow abstraction
-"""
+"""Tests for the Workflow abstraction."""
 from typing import Callable
 
 import pytest
 from airflow import DAG
 
-from dkist_processing_core import Workflow
-
 
 def test_workflow_metadata(workflow):
     """
-    Given: A workflow instance
-    When: accessing attributes
-    Then: Tha values are properly assigned
+    Given: A workflow instance.
+    When: accessing attributes.
+    Then: Tha values are properly assigned.
     """
     workflow_instance, category, name, version = workflow
 
@@ -30,10 +26,10 @@ def test_workflow_metadata(workflow):
 
 def test_workflow_add_node(workflow_tasks, workflow):
     """
-    Given: A set of tasks and a workflow instance
+    Given: A set of tasks and a workflow instance.
     When: Adding the tasks to the workflow in the
-      structure of A >> [B, C] >> D
-    Then: the dag object owned by the workflow has the right structure
+      structure of A >> [B, C] >> D.
+    Then: the dag object owned by the workflow has the right structure.
     """
     workflow_instance, category, name, version = workflow
     TaskA, TaskB, TaskC, TaskD = workflow_tasks
@@ -70,9 +66,9 @@ def test_workflow_add_node(workflow_tasks, workflow):
 
 def test_invalid_workflow_add_node(workflow):
     """
-    Given: An invalid task (not inheriting from TaskBase)and a workflow instance
-    When: Adding the task to the workflow
-    Then: Get a TypeError
+    Given: An invalid task (not inheriting from TaskBase)and a workflow instance.
+    When: Adding the task to the workflow.
+    Then: Get a TypeError.
     """
     workflow_instance, _, _, _ = workflow
 
@@ -92,9 +88,9 @@ def test_invalid_workflow_add_node(workflow):
 )
 def test_tag_db_dunder(workflow, func: Callable, attr):
     """
-    Given: Connection to a tag database
-    When: retrieving dunder method that should be implemented
-    Then: It is implemented
+    Given: Connection to a tag database.
+    When: retrieving dunder method that should be implemented.
+    Then: It is implemented.
     """
     workflow_instance, _, _, _ = workflow
 
